import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as TotalTLSAPI from 'cloudflare/resources/acm/total-tls';
export declare class TotalTLS extends APIResource {
    /**
     * Set Total TLS Settings or disable the feature for a Zone.
     */
    create(params: TotalTLSCreateParams, options?: Core.RequestOptions): Core.APIPromise<TotalTLSCreateResponse>;
    /**
     * Get Total TLS Settings for a Zone.
     */
    get(params: TotalTLSGetParams, options?: Core.RequestOptions): Core.APIPromise<TotalTLSGetResponse>;
}
export interface TotalTLSCreateResponse {
    /**
     * The Certificate Authority that Total TLS certificates will be issued through.
     */
    certificate_authority?: 'google' | 'lets_encrypt';
    /**
     * If enabled, Total TLS will order a hostname specific TLS certificate for any
     * proxied A, AAAA, or CNAME record in your zone.
     */
    enabled?: boolean;
    /**
     * The validity period in days for the certificates ordered via Total TLS.
     */
    validity_days?: 90;
}
export interface TotalTLSGetResponse {
    /**
     * The Certificate Authority that Total TLS certificates will be issued through.
     */
    certificate_authority?: 'google' | 'lets_encrypt';
    /**
     * If enabled, Total TLS will order a hostname specific TLS certificate for any
     * proxied A, AAAA, or CNAME record in your zone.
     */
    enabled?: boolean;
    /**
     * The validity period in days for the certificates ordered via Total TLS.
     */
    validity_days?: 90;
}
export interface TotalTLSCreateParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: If enabled, Total TLS will order a hostname specific TLS certificate
     * for any proxied A, AAAA, or CNAME record in your zone.
     */
    enabled: boolean;
    /**
     * Body param: The Certificate Authority that Total TLS certificates will be issued
     * through.
     */
    certificate_authority?: 'google' | 'lets_encrypt';
}
export interface TotalTLSGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace TotalTLS {
    export import TotalTLSCreateResponse = TotalTLSAPI.TotalTLSCreateResponse;
    export import TotalTLSGetResponse = TotalTLSAPI.TotalTLSGetResponse;
    export import TotalTLSCreateParams = TotalTLSAPI.TotalTLSCreateParams;
    export import TotalTLSGetParams = TotalTLSAPI.TotalTLSGetParams;
}
//# sourceMappingURL=total-tls.d.ts.map