"use strict";
// File generated from our OpenAPI spec by Stainless.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Zones = void 0;
const resource_1 = require("cloudflare/resource");
const error_1 = require("cloudflare/error");
class Zones extends resource_1.APIResource {
    /**
     * Add a zone as a member of a particular address map.
     */
    update(addressMapId, params, options) {
        const { zone_id, account_id } = params;
        if (!account_id && !zone_id) {
            throw new error_1.CloudflareError('You must provide either account_id or zone_id.');
        }
        if (account_id && zone_id) {
            throw new error_1.CloudflareError('You cannot provide both account_id and zone_id.');
        }
        const { accountOrZone, accountOrZoneId } = account_id ?
            {
                accountOrZone: 'accounts',
                accountOrZoneId: account_id,
            }
            : {
                accountOrZone: 'zones',
                accountOrZoneId: zone_id,
            };
        return this._client.put(`/accounts/${accountOrZone}/addressing/address_maps/${addressMapId}/zones/${accountOrZoneId}`, options)._thenUnwrap((obj) => obj.result);
    }
    /**
     * Remove a zone as a member of a particular address map.
     */
    delete(addressMapId, params, options) {
        const { zone_id, account_id } = params;
        if (!account_id && !zone_id) {
            throw new error_1.CloudflareError('You must provide either account_id or zone_id.');
        }
        if (account_id && zone_id) {
            throw new error_1.CloudflareError('You cannot provide both account_id and zone_id.');
        }
        const { accountOrZone, accountOrZoneId } = account_id ?
            {
                accountOrZone: 'accounts',
                accountOrZoneId: account_id,
            }
            : {
                accountOrZone: 'zones',
                accountOrZoneId: zone_id,
            };
        return this._client.delete(`/accounts/${accountOrZone}/addressing/address_maps/${addressMapId}/zones/${accountOrZoneId}`, options)._thenUnwrap((obj) => obj.result);
    }
}
exports.Zones = Zones;
(function (Zones) {
})(Zones = exports.Zones || (exports.Zones = {}));
//# sourceMappingURL=zones.js.map