import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as TldsAPI from 'cloudflare/resources/radar/email/security/top/tlds/tlds';
import * as MaliciousAPI from 'cloudflare/resources/radar/email/security/top/tlds/malicious';
import * as SpamAPI from 'cloudflare/resources/radar/email/security/top/tlds/spam';
import * as SpoofAPI from 'cloudflare/resources/radar/email/security/top/tlds/spoof';
export declare class Tlds extends APIResource {
    malicious: MaliciousAPI.Malicious;
    spam: SpamAPI.Spam;
    spoof: SpoofAPI.Spoof;
    /**
     * Get the top TLDs by email messages. Values are a percentage out of the total
     * emails.
     */
    get(query?: TldGetParams, options?: Core.RequestOptions): Core.APIPromise<TldGetResponse>;
    get(options?: Core.RequestOptions): Core.APIPromise<TldGetResponse>;
}
export interface TldGetResponse {
    meta: TldGetResponse.Meta;
    top_0: Array<TldGetResponse.Top0>;
}
export declare namespace TldGetResponse {
    interface Meta {
        dateRange: Array<Meta.DateRange>;
        lastUpdated: string;
        confidenceInfo?: Meta.ConfidenceInfo;
    }
    namespace Meta {
        interface DateRange {
            /**
             * Adjusted end of date range.
             */
            endTime: string;
            /**
             * Adjusted start of date range.
             */
            startTime: string;
        }
        interface ConfidenceInfo {
            annotations?: Array<ConfidenceInfo.Annotation>;
            level?: number;
        }
        namespace ConfidenceInfo {
            interface Annotation {
                dataSource: string;
                description: string;
                eventType: string;
                isInstantaneous: unknown;
                endTime?: string;
                linkedUrl?: string;
                startTime?: string;
            }
        }
    }
    interface Top0 {
        name: string;
        value: string;
    }
}
export interface TldGetParams {
    /**
     * Filter for arc (Authenticated Received Chain).
     */
    arc?: Array<'PASS' | 'NONE' | 'FAIL'>;
    /**
     * End of the date range (inclusive).
     */
    dateEnd?: Array<string>;
    /**
     * For example, use `7d` and `7dControl` to compare this week with the previous
     * week. Use this parameter or set specific start and end dates (`dateStart` and
     * `dateEnd` parameters).
     */
    dateRange?: Array<'1d' | '2d' | '7d' | '14d' | '28d' | '12w' | '24w' | '52w' | '1dControl' | '2dControl' | '7dControl' | '14dControl' | '28dControl' | '12wControl' | '24wControl'>;
    /**
     * Array of datetimes to filter the start of a series.
     */
    dateStart?: Array<string>;
    /**
     * Filter for dkim.
     */
    dkim?: Array<'PASS' | 'NONE' | 'FAIL'>;
    /**
     * Filter for dmarc.
     */
    dmarc?: Array<'PASS' | 'NONE' | 'FAIL'>;
    /**
     * Format results are returned in.
     */
    format?: 'JSON' | 'CSV';
    /**
     * Limit the number of objects in the response.
     */
    limit?: number;
    /**
     * Array of names that will be used to name the series in responses.
     */
    name?: Array<string>;
    /**
     * Filter for spf.
     */
    spf?: Array<'PASS' | 'NONE' | 'FAIL'>;
    /**
     * Filter for TLDs by category.
     */
    tldCategory?: 'CLASSIC' | 'COUNTRY';
    /**
     * Filter for tls version.
     */
    tlsVersion?: Array<'TLSv1_0' | 'TLSv1_1' | 'TLSv1_2' | 'TLSv1_3'>;
}
export declare namespace Tlds {
    export import TldGetResponse = TldsAPI.TldGetResponse;
    export import TldGetParams = TldsAPI.TldGetParams;
    export import Malicious = MaliciousAPI.Malicious;
    export import MaliciousGetResponse = MaliciousAPI.MaliciousGetResponse;
    export import MaliciousGetParams = MaliciousAPI.MaliciousGetParams;
    export import Spam = SpamAPI.Spam;
    export import SpamGetResponse = SpamAPI.SpamGetResponse;
    export import SpamGetParams = SpamAPI.SpamGetParams;
    export import Spoof = SpoofAPI.Spoof;
    export import SpoofGetResponse = SpoofAPI.SpoofGetResponse;
    export import SpoofGetParams = SpoofAPI.SpoofGetParams;
}
//# sourceMappingURL=tlds.d.ts.map