import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as TSIGsAPI from 'cloudflare/resources/secondary-dns/tsigs';
export declare class TSIGs extends APIResource {
    /**
     * Create TSIG.
     */
    create(params: TSIGCreateParams, options?: Core.RequestOptions): Core.APIPromise<SecondaryDNSTSIG>;
    /**
     * Modify TSIG.
     */
    update(tsigId: unknown, params: TSIGUpdateParams, options?: Core.RequestOptions): Core.APIPromise<SecondaryDNSTSIG>;
    /**
     * List TSIGs.
     */
    list(params: TSIGListParams, options?: Core.RequestOptions): Core.APIPromise<TSIGListResponse | null>;
    /**
     * Delete TSIG.
     */
    delete(tsigId: unknown, params: TSIGDeleteParams, options?: Core.RequestOptions): Core.APIPromise<TSIGDeleteResponse>;
    /**
     * Get TSIG.
     */
    get(tsigId: unknown, params: TSIGGetParams, options?: Core.RequestOptions): Core.APIPromise<SecondaryDNSTSIG>;
}
export interface SecondaryDNSTSIG {
    id: unknown;
    /**
     * TSIG algorithm.
     */
    algo: string;
    /**
     * TSIG key name.
     */
    name: string;
    /**
     * TSIG secret.
     */
    secret: string;
}
export type TSIGListResponse = Array<SecondaryDNSTSIG>;
export interface TSIGDeleteResponse {
    id?: unknown;
}
export interface TSIGCreateParams {
    /**
     * Path param:
     */
    account_id: unknown;
    /**
     * Body param: TSIG algorithm.
     */
    algo: string;
    /**
     * Body param: TSIG key name.
     */
    name: string;
    /**
     * Body param: TSIG secret.
     */
    secret: string;
}
export interface TSIGUpdateParams {
    /**
     * Path param:
     */
    account_id: unknown;
    /**
     * Body param: TSIG algorithm.
     */
    algo: string;
    /**
     * Body param: TSIG key name.
     */
    name: string;
    /**
     * Body param: TSIG secret.
     */
    secret: string;
}
export interface TSIGListParams {
    account_id: unknown;
}
export interface TSIGDeleteParams {
    account_id: unknown;
}
export interface TSIGGetParams {
    account_id: unknown;
}
export declare namespace TSIGs {
    export import SecondaryDNSTSIG = TSIGsAPI.SecondaryDNSTSIG;
    export import TSIGListResponse = TSIGsAPI.TSIGListResponse;
    export import TSIGDeleteResponse = TSIGsAPI.TSIGDeleteResponse;
    export import TSIGCreateParams = TSIGsAPI.TSIGCreateParams;
    export import TSIGUpdateParams = TSIGsAPI.TSIGUpdateParams;
    export import TSIGListParams = TSIGsAPI.TSIGListParams;
    export import TSIGDeleteParams = TSIGsAPI.TSIGDeleteParams;
    export import TSIGGetParams = TSIGsAPI.TSIGGetParams;
}
//# sourceMappingURL=tsigs.d.ts.map