import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as EventsAPI from 'cloudflare/resources/user/load-balancers/analytics/events';
export declare class Events extends APIResource {
    /**
     * List origin health changes.
     */
    list(query?: EventListParams, options?: Core.RequestOptions): Core.APIPromise<EventListResponse | null>;
    list(options?: Core.RequestOptions): Core.APIPromise<EventListResponse | null>;
}
export interface LoadBalancingAnalytics {
    id?: number;
    origins?: Array<unknown>;
    pool?: unknown;
    timestamp?: string;
}
export type EventListResponse = Array<LoadBalancingAnalytics>;
export interface EventListParams {
    /**
     * If true, filter events where the origin status is healthy. If false, filter
     * events where the origin status is unhealthy.
     */
    origin_healthy?: boolean;
    /**
     * The name for the origin to filter.
     */
    origin_name?: string;
    /**
     * If true, filter events where the pool status is healthy. If false, filter events
     * where the pool status is unhealthy.
     */
    pool_healthy?: boolean;
    pool_id?: string;
    /**
     * The name for the pool to filter.
     */
    pool_name?: string;
    /**
     * Start date and time of requesting data period in the ISO8601 format.
     */
    since?: string;
    /**
     * End date and time of requesting data period in the ISO8601 format.
     */
    until?: string;
}
export declare namespace Events {
    export import LoadBalancingAnalytics = EventsAPI.LoadBalancingAnalytics;
    export import EventListResponse = EventsAPI.EventListResponse;
    export import EventListParams = EventsAPI.EventListParams;
}
//# sourceMappingURL=events.d.ts.map