import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as MinifyAPI from 'cloudflare/resources/zones/settings/minify';
export declare class Minify extends APIResource {
    /**
     * Automatically minify certain assets for your website. Refer to
     * [Using Cloudflare Auto Minify](https://support.cloudflare.com/hc/en-us/articles/200168196)
     * for more information.
     */
    edit(params: MinifyEditParams, options?: Core.RequestOptions): Core.APIPromise<ZonesMinify>;
    /**
     * Automatically minify certain assets for your website. Refer to
     * [Using Cloudflare Auto Minify](https://support.cloudflare.com/hc/en-us/articles/200168196)
     * for more information.
     */
    get(params: MinifyGetParams, options?: Core.RequestOptions): Core.APIPromise<ZonesMinify>;
}
/**
 * Automatically minify certain assets for your website. Refer to
 * [Using Cloudflare Auto Minify](https://support.cloudflare.com/hc/en-us/articles/200168196)
 * for more information.
 */
export interface ZonesMinify {
    /**
     * Zone setting identifier.
     */
    id: 'minify';
    /**
     * Current value of the zone setting.
     */
    value: ZonesMinify.Value;
    /**
     * Whether or not this setting can be modified for this zone (based on your
     * Cloudflare plan level).
     */
    editable?: true | false;
    /**
     * last time this setting was modified.
     */
    modified_on?: string | null;
}
export declare namespace ZonesMinify {
    /**
     * Current value of the zone setting.
     */
    interface Value {
        /**
         * Automatically minify all CSS files for your website.
         */
        css?: 'on' | 'off';
        /**
         * Automatically minify all HTML files for your website.
         */
        html?: 'on' | 'off';
        /**
         * Automatically minify all JavaScript files for your website.
         */
        js?: 'on' | 'off';
    }
}
export interface MinifyEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Value of the zone setting.
     */
    value: MinifyEditParams.Value;
}
export declare namespace MinifyEditParams {
    /**
     * Value of the zone setting.
     */
    interface Value {
        /**
         * Automatically minify all CSS files for your website.
         */
        css?: 'on' | 'off';
        /**
         * Automatically minify all HTML files for your website.
         */
        html?: 'on' | 'off';
        /**
         * Automatically minify all JavaScript files for your website.
         */
        js?: 'on' | 'off';
    }
}
export interface MinifyGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace Minify {
    export import ZonesMinify = MinifyAPI.ZonesMinify;
    export import MinifyEditParams = MinifyAPI.MinifyEditParams;
    export import MinifyGetParams = MinifyAPI.MinifyGetParams;
}
//# sourceMappingURL=minify.d.ts.map