import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as NELAPI from 'cloudflare/resources/zones/settings/nel';
export declare class NEL extends APIResource {
    /**
     * Automatically optimize image loading for website visitors on mobile devices.
     * Refer to our [blog post](http://blog.cloudflare.com/nel-solving-mobile-speed)
     * for more information.
     */
    edit(params: NELEditParams, options?: Core.RequestOptions): Core.APIPromise<ZonesNEL>;
    /**
     * Enable Network Error Logging reporting on your zone. (Beta)
     */
    get(params: NELGetParams, options?: Core.RequestOptions): Core.APIPromise<ZonesNEL>;
}
/**
 * Enable Network Error Logging reporting on your zone. (Beta)
 */
export interface ZonesNEL {
    /**
     * Zone setting identifier.
     */
    id: 'nel';
    /**
     * Current value of the zone setting.
     */
    value: ZonesNEL.Value;
    /**
     * Whether or not this setting can be modified for this zone (based on your
     * Cloudflare plan level).
     */
    editable?: true | false;
    /**
     * last time this setting was modified.
     */
    modified_on?: string | null;
}
export declare namespace ZonesNEL {
    /**
     * Current value of the zone setting.
     */
    interface Value {
        enabled?: boolean;
    }
}
export interface NELEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Enable Network Error Logging reporting on your zone. (Beta)
     */
    value: ZonesNEL;
}
export interface NELGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace NEL {
    export import ZonesNEL = NELAPI.ZonesNEL;
    export import NELEditParams = NELAPI.NELEditParams;
    export import NELGetParams = NELAPI.NELGetParams;
}
//# sourceMappingURL=nel.d.ts.map