import * as Core from 'cloudflare/core';
import { APIResource } from 'cloudflare/resource';
import * as PolishAPI from 'cloudflare/resources/zones/settings/polish';
export declare class Polish extends APIResource {
    /**
     * Automatically optimize image loading for website visitors on mobile devices.
     * Refer to our [blog post](http://blog.cloudflare.com/polish-solving-mobile-speed)
     * for more information.
     */
    edit(params: PolishEditParams, options?: Core.RequestOptions): Core.APIPromise<ZonesPolish>;
    /**
     * Automatically optimize image loading for website visitors on mobile devices.
     * Refer to our [blog post](http://blog.cloudflare.com/polish-solving-mobile-speed)
     * for more information.
     */
    get(params: PolishGetParams, options?: Core.RequestOptions): Core.APIPromise<ZonesPolish>;
}
/**
 * Removes metadata and compresses your images for faster page load times. Basic
 * (Lossless): Reduce the size of PNG, JPEG, and GIF files - no impact on visual
 * quality. Basic + JPEG (Lossy): Further reduce the size of JPEG files for faster
 * image loading. Larger JPEGs are converted to progressive images, loading a
 * lower-resolution image first and ending in a higher-resolution version. Not
 * recommended for hi-res photography sites.
 */
export interface ZonesPolish {
    /**
     * ID of the zone setting.
     */
    id: 'polish';
    /**
     * Current value of the zone setting.
     */
    value: 'off' | 'lossless' | 'lossy';
    /**
     * Whether or not this setting can be modified for this zone (based on your
     * Cloudflare plan level).
     */
    editable?: true | false;
    /**
     * last time this setting was modified.
     */
    modified_on?: string | null;
}
export interface PolishEditParams {
    /**
     * Path param: Identifier
     */
    zone_id: string;
    /**
     * Body param: Removes metadata and compresses your images for faster page load
     * times. Basic (Lossless): Reduce the size of PNG, JPEG, and GIF files - no impact
     * on visual quality. Basic + JPEG (Lossy): Further reduce the size of JPEG files
     * for faster image loading. Larger JPEGs are converted to progressive images,
     * loading a lower-resolution image first and ending in a higher-resolution
     * version. Not recommended for hi-res photography sites.
     */
    value: ZonesPolish;
}
export interface PolishGetParams {
    /**
     * Identifier
     */
    zone_id: string;
}
export declare namespace Polish {
    export import ZonesPolish = PolishAPI.ZonesPolish;
    export import PolishEditParams = PolishAPI.PolishEditParams;
    export import PolishGetParams = PolishAPI.PolishGetParams;
}
//# sourceMappingURL=polish.d.ts.map